<?php

$lan = array(
  'existingusers' => "Utilisateurs Existants",
  'nonexistingusers' => "Utilisateurs Non Existants",
  'existcheckintro' => 'Page pour v&eacute;rifier l&rsquo;entr&eacute;e des utilisateurs dans la base de donn&eacute;es',
  'whatistype' => 'Quel est le type d&rsquo;information que vous souhaitez v&eacute;rifier',
  "foreignkey" => "Foreign Key (cl&eacute; &eacute;trang&egrave;re)",
  "email" => "Email",
  "continue" => "Continuer",
  "pastevalues" => "Ajouter les valeurs &agrave; v&eacute;rifier dans cette bo&icirc;te, une valeur par ligne",
);

?>